What the project has to do
==========================

Publishing Boy will read the contents of the
given folder, using glob recurent pattern
on *.md files.

It will run series of transformations
on each file, that will produce
a new, from a template, *.md file.
This file will be ready to process
by pelican static site generator.

And save it to /content folder in
flat structure (all files in folder).
